@@ -218,11 +218,11 @@ Graph = R6Class("Graph",
       types_src = self$pipeops[[src_id]]$output[get("name") == src_channel, c("train", "predict")]
       types_dst = self$pipeops[[dst_id]]$input[get("name") == dst_channel, c("train", "predict")]
 
-      if (!are_types_compatible(types_src$train, types_dst$train)) {
+      if (!are_types_compatible(strip_multiplicity_type(types_src$train), strip_multiplicity_type(types_dst$train))) {
         stopf("Output type of PipeOp %s during training (%s) incompatible with input type of PipeOp %s (%s)",
           src_id, types_src$train, dst_id, types_dst$train)
       }
-      if (!are_types_compatible(types_src$predict, types_dst$predict)) {
+      if (!are_types_compatible(strip_multiplicity_type(types_src$predict), strip_multiplicity_type(types_dst$predict))) {
         stopf("Output type of PipeOp %s during prediction (%s) incompatible with input type of PipeOp %s (%s)",
           src_id, types_src$predict, dst_id, types_dst$predict)
       }
